pub enum AuthMode {
None,
Optional,
Required,
Unset,
}Expand description
Certificate verification mode used for a session
Variants
None
Peer certificate is not checked (default on server) (insecure on client)
Optional
Peer certificate is checked, however the handshake continues even if verification failed; mbedtls_ssl_get_verify_result() can be called after the handshake is complete.
Required
Peer must present a valid certificate, handshake is aborted if verification failed. (default on client)
Unset
Used only for sni_authmode