pub struct ClientSessionConfig<'a> {
pub ca_chain: Option<Certificate<'a>>,
pub creds: Option<Credentials<'a>>,
pub server_name: Option<&'a CStr>,
pub auth_mode: AuthMode,
pub min_version: TlsVersion,
pub alpn_protocols: Option<&'a [&'a CStr]>,
}Expand description
Configuration for a TLS session
Fields
ca_chain: Option<Certificate<'a>>Trusted CA (Certificate Authority) chain to be used for certificate verification during the SSL/TLS handshake.
The CA chain should contain the trusted CA certificates that will be used to verify the server’s certificate by the client during the handshake.
creds: Option<Credentials<'a>>Optional client credentials used for authenticating the client to the server
server_name: Option<&'a CStr>The server name to verify in the certificate provided by the server Optional, because it can also be provided later
auth_mode: AuthModeCertificate verification mode. Can be overriden. By default, AuthMode::Required will be used
min_version: TlsVersionThe minimum TLS version that will be supported by a particular Session instance
alpn_protocols: Option<&'a [&'a CStr]>ALPN protocols
Implementations
Sourceimpl<'a> ClientSessionConfig<'a>
impl<'a> ClientSessionConfig<'a>