ServerSessionConfig

Struct ServerSessionConfig 

pub struct ServerSessionConfig<'a> {
    pub ca_chain: Option<Certificate<'a>>,
    pub creds: Credentials<'a>,
    pub auth_mode: AuthMode,
    pub min_version: TlsVersion,
    pub alpn_protocols: Option<&'a [&'a CStr]>,
}

Fields

ca_chain: Option<Certificate<'a>>

Trusted CA (Certificate Authority) chain to be used for certificate verification during the SSL/TLS handshake.

The CA chain should contain the trusted CA certificates that will be used to verify the client’s certificate by the server during the handshake.

creds: Credentials<'a>

Server credentials used for authenticating the server to the client

auth_mode: AuthMode

Client certificate verification mode. Can be overriden. By default, AuthMode::None will be used

min_version: TlsVersion

The minimum TLS version that will be supported by a particular Session instance

alpn_protocols: Option<&'a [&'a CStr]>

ALPN protocols

Implementations

Source

impl<'a> ServerSessionConfig<'a>

pub const fn new(creds: Credentials<'a>) -> Self